# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2020-07-06 08:51
from __future__ import unicode_literals

from django.db import migrations

try:
    from django.db.models import JSONField
except ImportError:
    from django.contrib.postgres.fields import JSONField


class Migration(migrations.Migration):

    dependencies = [
        ('whisperer', '0004_webhook_retry_count'),
    ]

    operations = [
        migrations.AddField(
            model_name='webhook',
            name='config',
            field=JSONField(default=dict),
        ),
    ]
