# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2023-12-14 09:09
from __future__ import unicode_literals

try:
    from django.db.models import JSONField
except ImportError:
    from django.contrib.postgres.fields import JSONField

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ('whisperer', '0006_auto_20200925_1710'),
    ]

    operations = [
        migrations.CreateModel(
            name='EventQueue',
            fields=[
                (
                    'id',
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name='ID'
                    )
                ),
                (
                    'created_date',
                    models.DateTimeField(
                        auto_now_add=True
                    )
                ),
                (
                    'modified_date',
                    models.DateTimeField(
                        auto_now=True,
                        db_index=True
                    )
                ),
                (
                    'uuid',
                    models.UUIDField(
                        db_index=True,
                        default=uuid.uuid4,
                        unique=True
                    )
                ),
                (
                    'hook_id',
                    models.PositiveIntegerField()
                ),
                (
                    'event_type',
                    models.CharField(
                        max_length=124
                    )
                ),
                (
                    'app_label',
                    models.CharField(
                        null=True,
                        blank=True,
                        max_length=124
                    )
                ),
                (
                    'model_name',
                    models.CharField(
                        null=True,
                        blank=True,
                        max_length=124
                    )
                ),
                (
                    'instance_pk',
                    models.PositiveIntegerField(
                        null=True
                    )
                ),
                (
                    'instance_dict',
                    JSONField(
                        default=dict
                    )
                ),
            ],
            options={
                'abstract': False,
            },
        ),
    ]