# Generated by Django 3.0.4 on 2020-04-01 08:47

from django.db import migrations

try:
    from django.db.models import JSONField
except ImportError:
    from django.contrib.postgres.fields import JSONField


class Migration(migrations.Migration):
    dependencies = [
        ('whisperer', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='webhook',
            name='additional_headers',
            field=JSONField(default=dict),
        ),
    ]
